:orphan:

User modules
============

The following modules help to perform calculations on physical quantities:

- :mod:`natu.config` - Configuration settings for :mod:`natu`
- :mod:`natu.units` - Module with all units defined by the :file:`\*.ini` files
  listed in :attr:`natu.config.definitions`
- :mod:`natu.groups` - Modules with groups of units
- :mod:`natu.math` - `Python math`_, adapted for use with physical quantities
- :mod:`natu.numpy` - :mod:`numpy`, adapted for use with physical quantities


.. _Python math: https://docs.python.org/3/library/math.html
